@@ -62,7 +62,7 @@ def summary(s):
         ci_lo = f'{round(ci_lo, 3):9}'
         ci_hi = f'{round(ci_hi, 3):9}'
 
-        summ += f"| {vari:{space}} |  {c_val:13} | {std_val:12} | {tv_val:10} | [{ci_lo:10}, {ci_lo:10}] |  {pb_val:6}   {sign:3} |\n"
+        summ += f"| {vari:{space}} |  {c_val:13} | {std_val:12} | {tv_val:10} | [{ci_lo:10}, {ci_hi:10}] |  {pb_val:6}   {sign:3} |\n"
     summ += f"============================================================================================================={add_sep}\n"
     summ += f"| Significance codes: 0. < *** < 0.001 < ** < 0.01 < * < 0.05 < . < 0.1 < '' < 1                            {add_sp}|\n"
     summ += f"============================================================================================================={add_sep}\n"
